{#
# This file is part of Invenio.
# Copyright (C) 2015, 2016, 2017 CERN.
#
# Invenio is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.
#}

{# Create Twitter card meta-tags.
 #
 # Configuration variable THEME_TWITTERHANDLE should be set to your Twitter
 # handle. See https://dev.twitter.com/cards/overview for details.
 #}
{%- macro meta_twittercard(title, description, card='summary', site='') %}
    <meta name="twitter:card" content="{{card}}" />
    <meta name="twitter:site" content="{{site or config.THEME_TWITTERHANDLE}}" />
    <meta name="twitter:title" content="{{title}}" />
    <meta name="twitter:description" content="{{description}}" />
{%- endmacro %}


{# Create OpenGraph meta-tags. #}
{%- macro meta_opengraph(title, description, url='', site_name='') %}
    <meta property="og:title" content="{{title}}" />
    <meta property="og:description" content="{{description}}" />
    <meta property="og:url" content="{{ url }}" />
    <meta property="og:site_name" content="{{ site_name or config.THEME_SITENAME }}" />
{%- endmacro %}


{# Create HighWire Press meta-tags. #}
{%- macro meta_highwire(title, description, authors=[], publisher='', publication_date='', doi='', keywords=[], url='', pdf_url='') %}
    <meta name="description" content="{{description}}" />
    <meta name="citation_title" content="{{title}}" />
    {%- for a in authors %}
    <meta name="citation_author" content="{{a}}" />
    {%- endfor %}
    {%- for c in contributors %}
    <meta name="citation_contributor" content="{{c}}" />
    {%- endfor %}
    {%- if publisher %}
    <meta name="citation_publisher" content="{{publisher}}" />
    {%- endif %}
    {%- if publication_date %}
    <meta name="citation_publication_date" content="{{publication_date|to_arrow|format_arrow('YYYY/MM/DD')}}" />
    {%- endif %}
    {%- if doi %}
    <meta name="citation_doi" content="{{doi}}" />
    {%- endif %}
    {%- for k in keywords %}
    <meta name="citation_keywords" content="{{k}}" />
    {%- endfor %}
    {%- if url %}
    <meta name="citation_abstract_html_url" content="{{url}}" />
    {%- endif %}
    {%- if pdf_url %}
    <meta name="citation_pdf_url" content="{{pdf_url}}" />
    {%- endif %}
{%- endmacro %}
